#!/usr/bin/env Rscript --quiet --vanilla

# -----------------------------------------------------------------------------
# Copyright 2019 Dave Jarvis
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
# -----------------------------------------------------------------------------

library( 'knitr' )
library( 'yaml' )
library( 'rjson' )
library( 'tools' ) 
library( 'pander' ) 
library( 'ggplot2' ) 

source( 'cardinal.R' )
source( 'excursion.R' )
source( 'climate.R' )

# Read the command-line arguments.
args <- commandArgs( trailingOnly = TRUE )

# Redefine the arguments as variables.
file.yaml <- paste( args[1] )
file.rmd <- paste( args[2] )
dir.artefacts <- paste( args[3] )
file.md <- paste0(
  paste( sep='/',
    dir.artefacts,
    file_path_sans_ext( file.rmd )
  ), '.md' )

# Load interpolated strings into an object named 'v'.
v <- yaml.load_file( file.yaml )

# Compute, replace, and export the R expressions.
knit( file.rmd, file.md )

